==> haskell-scotty-0.22-195-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-scotty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 scotty
version:              0.22
visibility:           public
id:                   scotty-0.22-2fGOid8kmRsJtHMWtKiLqx
key:                  scotty-0.22-2fGOid8kmRsJtHMWtKiLqx
license:              BSD-3-Clause
copyright:            (c) 2012-Present, Andrew Farmer and the Scotty contributors
maintainer:           The Scotty maintainers
author:               Andrew Farmer <xichekolas@gmail.com>
stability:            experimental
homepage:             https://github.com/scotty-web/scotty
synopsis:
    Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp

description:
    A Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp.

    @
    &#123;-&#35; LANGUAGE OverloadedStrings &#35;-&#125;

    import Web.Scotty

    main = scotty 3000 $
    &#32;&#32;get &#34;/:word&#34; $ do
    &#32;&#32;&#32;&#32;beam <- pathParam &#34;word&#34;
    &#32;&#32;&#32;&#32;html $ mconcat [&#34;&#60;h1&#62;Scotty, &#34;, beam, &#34; me up!&#60;/h1&#62;&#34;]
    @


    Scotty is the cheap and cheerful way to write RESTful, declarative web applications.

    * A page is as simple as defining the verb, url pattern, and Text content.

    * It is template-language agnostic. Anything that returns a Text value will do.

    * Conforms to WAI Application interface.

    * Uses very fast Warp webserver by default.

    As for the name: Sinatra + Warp = Scotty.

    [WAI] <http://hackage.haskell.org/package/wai>

    [Warp] <http://hackage.haskell.org/package/warp>

category:             Web
abi:                  9dbdb2e9c15bb9f485530bd2a2e4f8b5
exposed:              True
exposed-modules:
    Web.Scotty Web.Scotty.Cookie Web.Scotty.Internal.Types
    Web.Scotty.Trans Web.Scotty.Trans.Strict

hidden-modules:
    Web.Scotty.Action Web.Scotty.Body Web.Scotty.Route
    Web.Scotty.Trans.Lazy Web.Scotty.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/scotty-0.22
library-dirs:         /usr/lib/ghc-9.6.6/site-local/scotty-0.22
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/scotty-0.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-scotty
hs-libraries:         HSscotty-0.22-2fGOid8kmRsJtHMWtKiLqx
depends:
    aeson-2.2.0.0-A8FqDK4tVym6hhqwC7qXFC base-4.18.2.1
    blaze-builder-0.4.4.1-6YvA6FikElyHVllPu1Wc2a bytestring-0.11.5.3
    case-insensitive-1.2.1.0-8vz9c08oERN6HaPlnW3IdE
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc exceptions-0.10.7
    http-types-0.12.4-5e6CiUpSQgfFBuPHItSqh0
    monad-control-1.0.3.1-B90N51zXti33IkVqO6Ac1t mtl-2.3.1
    network-3.1.4.0-6jdgASXXSsi4c1a8fEUR94
    regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag
    resourcet-1.2.6-HW1njfedMilBzSD7euG5nt stm-2.5.1.0 text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    transformers-base-0.4.6-Usy0DCTunwBDOI79QHLB2
    unliftio-0.2.25.1-HwD0xNwdhtzGuBcmiv6FkJ
    wai-3.2.4-9STWQp0whD3L0eUd8mHjKL
    wai-extra-3.1.18-Fw46bdjxY258YVWejEXL3c
    warp-3.4.0-CSt5ad6OW639eJcnRwa3Em

haddock-interfaces:   /usr/share/doc/haskell-scotty/html/scotty.haddock
haddock-html:         /usr/share/doc/haskell-scotty/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-scotty-0.22-196-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-scotty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 scotty
version:              0.22
visibility:           public
id:                   scotty-0.22-HyuPQ78xNi8EpvtF6A4iE0
key:                  scotty-0.22-HyuPQ78xNi8EpvtF6A4iE0
license:              BSD-3-Clause
copyright:            (c) 2012-Present, Andrew Farmer and the Scotty contributors
maintainer:           The Scotty maintainers
author:               Andrew Farmer <xichekolas@gmail.com>
stability:            experimental
homepage:             https://github.com/scotty-web/scotty
synopsis:
    Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp

description:
    A Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp.

    @
    &#123;-&#35; LANGUAGE OverloadedStrings &#35;-&#125;

    import Web.Scotty

    main = scotty 3000 $
    &#32;&#32;get &#34;/:word&#34; $ do
    &#32;&#32;&#32;&#32;beam <- pathParam &#34;word&#34;
    &#32;&#32;&#32;&#32;html $ mconcat [&#34;&#60;h1&#62;Scotty, &#34;, beam, &#34; me up!&#60;/h1&#62;&#34;]
    @


    Scotty is the cheap and cheerful way to write RESTful, declarative web applications.

    * A page is as simple as defining the verb, url pattern, and Text content.

    * It is template-language agnostic. Anything that returns a Text value will do.

    * Conforms to WAI Application interface.

    * Uses very fast Warp webserver by default.

    As for the name: Sinatra + Warp = Scotty.

    [WAI] <http://hackage.haskell.org/package/wai>

    [Warp] <http://hackage.haskell.org/package/warp>

category:             Web
abi:                  d894a97b927fa7d809ef5c40c94e4520
exposed:              True
exposed-modules:
    Web.Scotty Web.Scotty.Cookie Web.Scotty.Internal.Types
    Web.Scotty.Trans Web.Scotty.Trans.Strict

hidden-modules:
    Web.Scotty.Action Web.Scotty.Body Web.Scotty.Route
    Web.Scotty.Trans.Lazy Web.Scotty.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/scotty-0.22
library-dirs:         /usr/lib/ghc-9.6.6/site-local/scotty-0.22
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/scotty-0.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-scotty
hs-libraries:         HSscotty-0.22-HyuPQ78xNi8EpvtF6A4iE0
depends:
    aeson-2.2.0.0-4qLATSA6nfj1RfgXH6DMKK base-4.18.2.1
    blaze-builder-0.4.4.1-IalnSqFtizaBKkEQN83UwH bytestring-0.11.5.3
    case-insensitive-1.2.1.0-HFTLAepm1u61gRs0sAANH
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc exceptions-0.10.7
    http-types-0.12.4-Hj8jLUhN6rtnIgKEy5ynr
    monad-control-1.0.3.1-Cu2gag9g9XfDkjDNf9i6xZ mtl-2.3.1
    network-3.1.4.0-LsWsY6caX6uCNLTGwySDR3
    regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag
    resourcet-1.2.6-Dhf0zTJRCL3LnKPExtEFW6 stm-2.5.1.0 text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    transformers-base-0.4.6-EvxeInxseF6GyjY0h0BJce
    unliftio-0.2.25.1-2Z0SKAH7tah9jbYwGNfwFX
    wai-3.2.4-jofbQLzhHjJAjHqqQ1gcC
    wai-extra-3.1.18-1DuUCp3G6ik2vwmaLqFrh
    warp-3.4.0-3Ya7eYvnJ6uGkh1jTMqqfV

haddock-interfaces:   /usr/share/doc/haskell-scotty/html/scotty.haddock
haddock-html:         /usr/share/doc/haskell-scotty/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
